//
//  GBPrefsData.h
//  gBrowser
//
//  Created by Andreas Schwarz on Mon Dec 24 2001.
//  Copyright (c) 2001 __MyCompanyName__. All rights reserved.
//

#import <Cocoa/Cocoa.h>
#import <GBBasicsKit/GBBasicsKit.h>

@class GBFileItem;
@class GBBookmarksController;

@interface GBPrefsData : NSObject {
    NSUndoManager *undoManager;
    NSNotificationCenter *notificationCenter;
    GBFileItem *prefsFileItem;

    // Preferences    
    BOOL showThumbnailInfo;
	
    BOOL infoLabelValue;
    BOOL infoCreationValue;
    BOOL infoColorModelValue;
    BOOL infoDimensionsValue;
    BOOL infoExposureValue;
    BOOL infoICCValue;
    BOOL infoFileNameValue;
    BOOL infoFileSizeValue;
    BOOL infoFileTypeValue;
    BOOL infoKindValue;
    BOOL infoModificationValue;
    BOOL infoResolutionValue;
    BOOL infoDateTakenValue;
    BOOL infoHardwareValue;
    
    BOOL clusterSlideshowFolders;    
    BOOL slideshowFoldersInMenus;    
    BOOL useSlideshowFolderGrouping;
    BOOL loopSlideshowTimer;
    BOOL autohideSlideshowController;
	BOOL slideshowBlackoutOtherScreens;
	BOOL slideshowUsesInitialFile;

    BOOL collapsePreviewGenWindow;
    BOOL manualPreviewGenOnlyIfDifferent;
    BOOL sidebarAllowsKeyboardControl;
    
    BOOL imageViewerOpensFullscreen;
    BOOL imageViewerOpenOnLoad;
    
    BOOL saveSlideshowChanges;
    
    BOOL selectNextItemAfterFileMove;
    
    BOOL autohideImageViewer;
	
    BOOL imageShadowsCheckboxValue;
    BOOL textShadowsCheckboxValue;
        
    BOOL showSlideshowController;
    BOOL useSlideshowTimer;
	
	BOOL selectFirstThumbnailItem;
    
    BOOL renameOnEnterOnlyInFileList;
    BOOL renameOnEnterOnlyInPreviewPane;
        
    BOOL openImagesExternally;

	
	BOOL minimizeButtonPane;
	BOOL minimizeInfoPane;
	float infoPaneWidth;
	
	GBFileFilterTypes sidebarFileFilter;
	GBFileFilterTypes thumbnailPaneFileFilter;
	GBFileFilterTypes thumbnailPaneFolderFilter;
	
	
    BOOL autoExpandFileListDuringDrops;
    BOOL showFileCountInFileList;
	
    BOOL alignThumbnailsToBottom;
    
    GBOpenImageInOptions openInAppRadioValue;
        
    GBScreenOptions imageViewerScreen;
    GBScreenOptions slideshowScreen;
    
    GBOpenOptions imageViewerDisplayType;
    GBOpenOptions slideshowDisplayType;
    
    GBSortTypes slideshowSortType;
    
    GBOpenSizeOptions imageViewerDisplayPercentage;
    GBOpenSizeOptions slideshowDisplayPercentage;
    
    GBFileItem *openInAppFile;
    
    NSString *prefsWindowFrameString;
    NSString *browserWindowFrameString;
    NSString *imageViewerFrameString;
    
    NSString *statusString;
    
    int browserPreviewSizeValue;
    int previewGenerationSizeValue;
    
    int thumbnailQuality;
    
    int fileListWidth;
    int fileListSpacing;
    
    int imageOutlineThickness;
    
    int fileListFontHeight;
    
    NSColor *previewPaneBackgroundColor;
    NSColor *outlineImagesColor;
    NSColor *thumbnailsTextColor;

    NSColor *imageViewerBackgroundColor;
    NSColor *slideshowBackgroundColor;
    NSColor *slideshowTextColor;
    
    float slideshowTimerSeconds;
    
    BOOL outlineImagesCheckboxValue;
    
    int fadeSlideshowControlsValue;
    
    BOOL recursiveSlideshow;
    BOOL slideshowShowsFilename;
    
    BOOL minimizeFileList;
    
    BOOL createPreviewOnTheFly;

    BOOL fileListAlternatesBackground;
    BOOL reversePreviewsSort;
    BOOL reverseFileListSort;
    BOOL reverseSlideshowSort;
	
	BOOL autoexpandSidebarSelections;
    
    int fileListIconSize;
	
    NSInteger selectedInfoTab;
    
    GBPositions slideshowFilenamePosition;
        
    GBOpenOptions openOptionsValue;
    GBOpenSizeOptions openSizeOptionsValue;
    GBSortTypes previewsSortType;
    GBSortTypes fileListSortType;
	GBSortTypes previewsFolderSort;
    
    NSArray *currentFileListSelectedFiles;
    NSArray *currentFileListExpandedFiles;
    
    NSArray *openWithFiles;
    NSArray *moveToFiles;
    
    NSDictionary *toolbarConfiguration;
    NSDictionary *toolbarAliasDataDict;
    
    GBFileItem *sidebarRootFile;
    GBFileItem *preferredSidebarRootFile;
    
    NSFont *viewFont;
    NSFont *fileListFont;
    NSFont *slideshowTextFont;
	
	GBBookmarksController *sidebarBookmarksController;
	
	NSUInteger imageTileSize;
	NSUInteger autoTileSize;
}





// Initialization
- (id)initWithUndoManager:(NSUndoManager *)um forFileItem:(GBFileItem *)fileItem;

@property(retain) GBFileItem * prefsFileItem;
@property(readonly) GBFileItem * appPrefsFileItem;

- (NSUndoManager *)undoManager;

- (void)convertToDictionary:(NSMutableDictionary *)dictionary;
- (void)restoreFromDictionary:(NSDictionary *)dictionary;

- (NSMutableDictionary *)prefsDict;

- (void)processDictionaryForOldPrefs:(NSMutableDictionary *)prefsDict;
- (NSDictionary *)oldNewPrefsCompareDict;

- (void)readPrefsFile;
- (void)savePrefsFile;
- (void)savePrefsFileToURL:(NSURL *)url;

+ (NSString *)userPrefsFilePath;
+ (NSString *)userPrefsFolderPath;

- (void)restorePresetThumbAppearanceSettings:(NSUInteger)presetNumber;



    // Prefs
- (BOOL)setFileListRoot:(GBFileItem *)file;
- (GBFileItem *)getFileListRoot;
- (BOOL)setPreferredSidebarRoot:(GBFileItem *)file;
- (GBFileItem *)preferredSidebarRoot;

- (void)setCurrentFileListSelectedFiles:(NSArray *)files;
- (void)setCurrentFileListSelectedFilesNoNotification:(NSArray *)files;
- (NSArray *)getCurrentFileListSelectedFiles;

- (void)setCurrentFileListExpandedFiles:(NSArray *)expandedFiles;
- (NSArray *)getCurrentFileListExpandedFiles;

- (GBBookmarksController *)sidebarBookmarksController;

- (NSString *)getRootFolderName;

- (void)setAutoexpandSidebarSelections:(BOOL)expand;
- (BOOL)autoexpandSidebarSelections;

- (void)setImageViewerDisplayType:(GBOpenOptions)value;
- (GBOpenOptions)imageViewerDisplayType;
- (void)setSlideshowDisplayType:(GBOpenOptions)value;
- (GBOpenOptions)slideshowDisplayType;

- (BOOL)minimizeFileList;
- (void)setMinimizeFileList:(BOOL)minimize;

- (BOOL)selectFirstThumbnailItem;
- (void)setSelectFirstThumbnailItem:(BOOL)select;

- (void)setPreviewsSortType:(GBSortTypes)sortType;
- (GBSortTypes)getPreviewsSortType;
- (void)setPreviewsFolderSort:(GBSortTypes)sortType;
- (GBSortTypes)getPreviewsFolderSort;
- (void)setReversePreviewsSort:(BOOL)value;
- (BOOL)reversePreviewsSort;

- (void)setAutohideImageViewer:(BOOL)hide;
- (BOOL)autohideImageViewer;


- (void)setSelectedInfoTab:(NSInteger)tab;
- (BOOL)selectedInfoTab;

- (void)setSlideshowUsesInitialFile:(BOOL)value;
- (BOOL)slideshowUsesInitialFile;

- (void)setAlignThumbnailsToBottom:(BOOL)value;
- (BOOL)alignThumbnailsToBottom;

- (void)setSlideshowSortType:(GBSortTypes)sortType;
- (GBSortTypes)slideshowSortType;
- (void)setReverseSlideshowSort:(BOOL)value;
- (BOOL)reverseSlideshowSort;

- (void)setThumbnailQuality:(int)quality;
- (int)thumbnailQuality;

- (BOOL)imageViewerOpensFullscreen;
- (void)setImageViewerOpensFullscreen:(BOOL)value;
- (BOOL)imageViewerOpenOnLoad;
- (void)setImageViewerOpenOnLoad:(BOOL)value;
- (void)setImageViewerFrameString:(NSString *)frameString;
- (NSString *)imageViewerFrameString;

- (void)setImageViewerDisplayPercentage:(GBOpenSizeOptions)value;
- (GBOpenSizeOptions)imageViewerDisplayPercentage;
- (void)setSlideshowDisplayPercentage:(GBOpenSizeOptions)value;
- (GBOpenSizeOptions)slideshowDisplayPercentage;
- (void)setRecursiveSlideshow:(BOOL)value;
- (BOOL)recursiveSlideshow;
- (void)setClusterSlideshowFolders:(BOOL)value;
- (BOOL)clusterSlideshowFolders;

- (BOOL)minimizeInfoPane;
- (void)setMinimizeInfoPane:(BOOL)minimize;
- (BOOL)minimizeButtonPane;
- (void)setMinimizeButtonPane:(BOOL)minimize;
- (float)infoPaneWidth;
- (void)setInfoPaneWidth:(float)width;

- (void)setSaveSlideshowChanges:(BOOL)value;
- (BOOL)saveSlideshowChanges;

- (void)setUseSlideshowFolderGrouping:(BOOL)value;
- (BOOL)useSlideshowFolderGrouping;
- (void)setLoopSlideshowTimer:(BOOL)value;
- (BOOL)loopSlideshowTimer;
- (float)slideshowTimerSeconds;
- (void)setSlideshowTimerSeconds:(float)value;
- (void)setUseSlideshowTimer:(BOOL)value;
- (BOOL)useSlideshowTimer;
- (void)setSlideshowFoldersInMenus:(BOOL)value;
- (BOOL)slideshowFoldersInMenus;
- (void)setAutohideSlideshowController:(BOOL)value;
- (BOOL)autohideSlideshowController;

- (void)setSlideshowBlackoutOtherScreens:(BOOL)value;
- (BOOL)slideshowBlackoutOtherScreens;

- (void)setShowFileCountInFileList:(BOOL)value;
- (BOOL)showFileCountInFileList;

- (void)setRenameOnEnterOnlyInFileList:(BOOL)value;
- (BOOL)renameOnEnterOnlyInFileList;
- (void)setRenameOnEnterOnlyInPreviewPane:(BOOL)value;
- (BOOL)renameOnEnterOnlyInPreviewPane;

- (void)setCollapsePreviewGenWindow:(BOOL)value;
- (BOOL)collapsePreviewGenWindow;

- (void)setFileListSpacing:(int)value;
- (int)fileListSpacing;

- (void)setSlideshowShowsFilename:(BOOL)value;
- (BOOL)slideshowShowsFilename;

- (void)setFileListSortType:(GBSortTypes)sortType;
- (GBSortTypes)getFileListSortType;
- (void)setReverseFileListSort:(BOOL)value;
- (BOOL)reverseFileListSort;

- (void)setOpenOptionsValue:(GBOpenOptions)value;
- (GBOpenOptions)getOpenOptionsValue;

- (void)setOpenSizeOptionsValue:(GBOpenSizeOptions)value;
- (GBOpenSizeOptions)getOpenSizeOptionsValue;

- (void)setPrefsWindowFrameString:(NSString *)frameString;
- (NSString *)getPrefsWindowFrameString;

- (void)setBrowserWindowFrameString:(NSString *)frameString;
- (NSString *)getBrowserWindowFrameString;

- (void)setShowSlideshowController:(BOOL)value;
- (BOOL)showSlideshowController;

- (void)setSelectNextItemAfterFileMove:(BOOL)value;
- (BOOL)selectNextItemAfterFileMove;

- (void)setCreatePreviewOnTheFly:(BOOL)value;
- (BOOL)createPreviewOnTheFly;

- (void)setManualPreviewGenOnlyIfDifferent:(BOOL)value;
- (BOOL)manualPreviewGenOnlyIfDifferent;
- (void)setSidebarAllowsKeyboardControl:(BOOL)value;
- (BOOL)sidebarAllowsKeyboardControl;


- (void)setSidebarFileFilter:(GBFileFilterTypes)filter;
- (GBFileFilterTypes)sidebarFileFilter;
- (void)setThumbnailPaneFileFilter:(GBFileFilterTypes)filter;
- (GBFileFilterTypes)thumbnailPaneFileFilter;
- (void)setThumbnailPaneFolderFilter:(GBFileFilterTypes)filter;
- (GBFileFilterTypes)thumbnailPaneFolderFilter;


- (void)setImageViewerBackgroundColor:(NSColor *)color;
- (NSColor *)getImageViewerBackgroundColor;
- (void)setSlideshowBackgroundColor:(NSColor *)color;
- (NSColor *)getSlideshowBackgroundColor;
- (void)setSlideshowTextColor:(NSColor *)color;
- (NSColor *)slideshowTextColor;

- (void)setFileListAlternatesBackground:(BOOL)value;
- (BOOL)getFileListAlternatesBackground;

- (void)setOutlineImagesCheckboxValue:(BOOL)value;
- (BOOL)getOutlineImagesCheckboxValue;

- (void)setImageShadowsCheckboxValue:(BOOL)value;
- (BOOL)getImageShadowsCheckboxValue;

- (void)setTextShadowsCheckboxValue:(BOOL)value;
- (BOOL)getTextShadowsCheckboxValue;

- (void)setAutoExpandFileListDuringDrops:(BOOL)value;
- (BOOL)autoExpandFileListDuringDrops;

- (void)setOutlineImagesColor:(NSColor *)color;
- (NSColor *)getOutlineImagesColor;

- (NSColor *)getThumbnailsTextColor;
- (void)setThumbnailsTextColor:(NSColor *)color;
- (NSColor *)getPreviewPaneBackgroundColor;
- (void)setPreviewPaneBackgroundColor:(NSColor *)color;

- (void)setFadeSlideshowControlsValue:(int)value;
- (int)fadeSlideshowControlsValue;

- (void)setOpenWithFiles:(NSArray *)files;
- (NSArray *)openWithFiles;
- (void)setMoveToFiles:(NSArray *)files;
- (NSArray *)moveToFiles;

- (int)getFileListIconSize;
- (void)setFileListIconSize:(int)value;

- (void)setSlideshowTextFont:(NSFont *)font;
- (NSFont *)slideshowTextFont;
- (NSString *)slideshowTextFontName;
- (NSString *)slideshowTextFontSizeString;
- (NSString *)slideshowTextFontDisplayName;
- (void)setSlideshowTextFontName:(NSString *)name withSize:(float)size;

- (void)setThumbnailViewFontName:(NSString *)name withSize:(float)size;
- (void)setFileListFontName:(NSString *)name withSize:(float)size;

- (void)setThumbnailViewFont:(NSFont *)font;
- (NSFont *)getThumbnailViewFont;
- (NSString *)getThumbnailViewFontName;
- (NSString *)getThumbnailViewFontSizeString;
- (NSString *)getThumbnailViewFontDisplayName;

- (NSFont *)defaultFont;
- (NSString *)getFileListFontName;
- (NSString *)getFileListFontSizeString;
- (NSString *)getFileListFontDisplayName;

- (void)setImageViewerScreen:(GBScreenOptions)screen;
- (GBScreenOptions)imageViewerScreen;
- (void)setSlideshowScreen:(GBScreenOptions)screen;
- (GBScreenOptions)slideshowScreen;
- (void)setSlideshowFilenamePosition:(GBPositions)pos;
- (GBPositions)slideshowFilenamePosition;

- (void)setBrowserPreviewSizeValue:(int)value;
- (int)getBrowserPreviewSizeValue;
- (void)setPreviewGenerationSizeValue:(int)value;
- (int)getPreviewGenerationSizeValue;

- (void)setFileListWidth:(int)value;
- (int)getFileListWidth;
- (int)getFileListFontHeight;
- (NSFont *)getFileListFont;
- (void)setFileListFont:(NSFont *)font;

- (void)setImageOutlineThickness:(int)thickness;
- (int)imageOutlineThickness;

- (void)setOpenInAppRadioValue:(int)value;
- (int)getOpenInAppRadioValue;
- (BOOL)setOpenInAppFile:(GBFileItem *)file;
- (GBFileItem *)getOpenInAppFile;
- (NSString *)getOpenInAppFileName;

- (void)setOpenImagesExternally:(BOOL)value;
- (BOOL)openImagesExternally;

- (void)setShowThumbnailInfo:(BOOL)value;
- (BOOL)showThumbnailInfo;
- (void)setInfoColorModelValue:(BOOL)value;
- (BOOL)getInfoColorModelValue;
- (void)setInfoExposureValue:(BOOL)value;
- (BOOL)getInfoExposureValue;
- (void)setInfoICCValue:(BOOL)value;
- (BOOL)getInfoICCValue;
- (void)setInfoDimensionsValue:(BOOL)value;
- (BOOL)getInfoDimensionsValue;
- (void)setInfoFileNameValue:(BOOL)value;
- (BOOL)getInfoFileNameValue;
- (void)setInfoFileSizeValue:(BOOL)value;
- (BOOL)getInfoFileSizeValue;
- (void)setInfoFileTypeValue:(BOOL)value;
- (BOOL)getInfoFileTypeValue;
- (void)setInfoKindValue:(BOOL)value;
- (BOOL)getInfoKindValue;
- (void)setInfoModificationValue:(BOOL)value;
- (BOOL)getInfoModificationValue;
- (void)setInfoCreationValue:(BOOL)value;
- (BOOL)getInfoCreationValue;
- (void)setInfoLabelValue:(BOOL)value;
- (BOOL)getInfoLabelValue;
- (void)setInfoResolutionValue:(BOOL)value;
- (BOOL)getInfoResolutionValue;
- (void)setInfoHardwareValue:(BOOL)value;
- (BOOL)getInfoHardwareValue;
- (void)setInfoDateTakenValue:(BOOL)value;
- (BOOL)getInfoDateTakenValue;


- (NSUInteger)imageTileSize;
- (void)setImageTileSize:(NSUInteger)size;
- (NSUInteger)autoTileSize;
- (void)setAutoTileSize:(NSUInteger)size;


- (void)setStatusString:(NSString *)status;
- (NSString *)getStatusString;

- (void)setToolbarConfiguration:(NSDictionary *)dict;
- (NSDictionary *)getToolbarConfiguration;
- (void)setToolbarFilesDict:(NSDictionary *)dict;
- (NSDictionary *)getToolbarFilesDict;



@end

extern NSString *GBPrefsSavingNotification;
extern NSString *GBPrefsDeallocNotification;

extern NSString *GBSidebarFiltersChangedNotification;
extern NSString *GBThumbnailFiltersChangedNotification;

extern NSString *GBImageTileInfoChangedNotification;

extern NSString *GBSidebarAllowsKeyboardControlChangedNotification;
extern NSString *GBManualPreviewGenOnlyIfDifferentChangedNotification;
extern NSString *GBCollapsePreviewGenWindowChangedNotification;
extern NSString *GBSelectnextItemAfterFileMoveChangedNotification;
extern NSString *GBThumbnailQualityChangedNotification;
extern NSString *GBBrowserPreviewSizeValueChangedNotification;
extern NSString *GBPreviewGenerationSizeValueChangedNotification;
extern NSString *GBPreviewsSortTypeChangedNotification;
extern NSString *GBOutlineImagesCheckboxChangedNotification;
extern NSString *GBOutlineImagesThicknessChangedNotification;
extern NSString *GBPreviewPaneBackgroundColorChangedNotification;
extern NSString *GBOutlineImagesColorChangedNotification;
extern NSString *GBAlignThumbnailsChangedNotification;
extern NSString *GBImageShadowsCheckboxChangedNotification;
extern NSString *GBTextShadowsCheckboxChangedNotification;
extern NSString *GBCreatePreviewOnTheFlyChangedNotification;
extern NSString *GBRenameOnEnterOnlyInPreviewPaneChangedNotification;
extern NSString *GBThumbnailViewFontChangedNotification;
extern NSString *GBThumbnailsTextColorChangedNotification;
extern NSString *GBSelectFirstThumbnailItemChangedNotification;

extern NSString *toolbarItemNeedsAddingNotification;
extern NSString *toolbarItemClickedNotification;

extern NSString *GBSidebarBookmarkFilesChangedNotification;

extern NSString *GBOpenWithItemsChangedNotification;
extern NSString *GBMoveToItemsChangedNotification;

extern NSString *GBSlideshowControllerAutohideChangedNotification;
extern NSString *GBSlideshowFolderGroupingChangedNotification;
extern NSString *GBRecursiveSlideshowChangedNotification;
extern NSString *GBClusterSlideshowFoldersChangedNotification;
extern NSString *GBSlideshowControllerFadeChangedNotification;
extern NSString *GBSlideshowScreenOptionsChangedNotification;
extern NSString *GBSlideshowTextColorChangedNotification;
extern NSString *GBSlideshowFilenamePositionChangedNotification;
extern NSString *GBSlideshowShowFilenameChangedNotification;
extern NSString *GBSlideshowTextFontChangedNotification;
extern NSString *GBSlideshowBackgroundColorChangedNotification;
extern NSString *GBSlideshowPercentageChangedNotification;
extern NSString *GBSlideshowDisplayTypeChangedNotification;
extern NSString *GBLoopSlideshowTimerChangedNotification;
extern NSString *GBSlideshowSortTypeChangedNotification;
extern NSString *GBShowSlideshowControllerChangedNotification;
extern NSString *GBSlideshowTimerSecondsChangedNotification;
extern NSString *GBUseSlideshowTimerChangedNotification;
extern NSString *GBSlideshowFoldersInMenusChangedNotification;
extern NSString *GBSaveSlideshowChangesChangedNotification;
extern NSString *GBSlideshowBlackoutChangedNotification;
extern NSString *GBSlideshowUsesInitialFileChangedNotification;

extern NSString *GBImageViewerOpenFullscreenChangedNotification;
extern NSString *GBImageViewerOpenOnLoadChangedNotification;
extern NSString *GBImageViewerScreenOptionsChangedNotification;
extern NSString *GBImageViewerBackgroundColorChangedNotification;
extern NSString *GBImageViewerPercentageChangedNotification;
extern NSString *GBImageViewerDisplayTypeChangedNotification;
extern NSString *GBAutohideImageViewerChangedNotification;

extern NSString *GBAutoexpandSidebarSelectionsChangedNotification;
extern NSString *GBFileListPathChangedNotification;
extern NSString *GBFileListPathResetNotification;
extern NSString *GBShowFileCountInFileListChangedNotification;
extern NSString *GBRootFolderNameTextChangedNotification;
extern NSString *GBFileListAltBGCheckboxChangedNotification;
extern NSString *GBSidebarIconSizeChangedNotification;
extern NSString *GBListFontChangedNotification;
extern NSString *GBFileListSelectedPathsChangedNotification;
extern NSString *GBFileListAutoExpandChangedNotification;
extern NSString *GBFileListSortTypeChangedNotification;
extern NSString *GBFileListExpandedItemsChangedNotification;
extern NSString *GBRenameOnEnterOnlyInFileListChangedNotification;
extern NSString *GBFileListSpacingChangedNotification;
extern NSString *GBFileListMinimizeChangedNotification;
extern NSString *GBPreferredSidebarRootChangedNotification;

extern NSString *GBOpenOptionsValueChangedNotification;
extern NSString *GBOpenSizeOptionsValueChangedNotification;
extern NSString *GBOpenInAppRadioValueChangedNotification;
extern NSString *GBOpenInAppPathValueChangedNotification;
extern NSString *GBOpenInAppNameValueChangedNotification;
extern NSString *GBOpenImagesExternallyChangedNotification;

extern NSString *GBMinimizeInfoPaneChangedNotification;
extern NSString *GBThumbnailInfoChangedNotification;

extern NSString *GBPrefsWindowFrameStringChangedNotification;
extern NSString *GBBrowserWindowFrameStringChangedNotification;

extern NSString *GBStatusStringChangedNotification;


